@@ -1,5 +1,4 @@
 #!/usr/bin/python3
-# -*- coding: utf-8 -*-
 #
 # Univention App Center
 #  univention-app base module for installing, uninstalling, upgrading an app
@@ -116,7 +115,7 @@ class InstallRemoveUpgrade(Register):
             # different, please remember to to inform the user about the output
             # of the scripts!
         else:
-            self.log('Potential script hook folder is unused: {folder}'.format(folder=directory))
+            self.log(f'Potential script hook folder is unused: {directory}')
 
     def do_it(self, args):
         i = -1
